Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(64)

Unified Diff: third_party/mojo/src/mojo/edk/system/remote_producer_data_pipe_impl.cc

Issue 1019173002: Update mojo sdk to rev 7214b7ec7d27563b2666afad86cf1c5895c56c18 (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Keep permission service alive if embedder drops requests Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/mojo/src/mojo/edk/system/remote_producer_data_pipe_impl.cc
diff --git a/third_party/mojo/src/mojo/edk/system/remote_producer_data_pipe_impl.cc b/third_party/mojo/src/mojo/edk/system/remote_producer_data_pipe_impl.cc
index 7cd2447fd0079a5dfbd42df39089ba66fe6b80f8..3c1a0b26de54bd2fe1c2323cc332d26ab52e5293 100644
--- a/third_party/mojo/src/mojo/edk/system/remote_producer_data_pipe_impl.cc
+++ b/third_party/mojo/src/mojo/edk/system/remote_producer_data_pipe_impl.cc
@@ -28,11 +28,11 @@ bool ValidateIncomingMessage(size_t element_num_bytes,
size_t capacity_num_bytes,
size_t current_num_bytes,
const MessageInTransit* message) {
- // We should only receive endpoint messages.
- DCHECK_EQ(message->type(), MessageInTransit::kTypeEndpoint);
+ // We should only receive endpoint client messages.
+ DCHECK_EQ(message->type(), MessageInTransit::kTypeEndpointClient);
// But we should check the subtype; only take data messages.
- if (message->subtype() != MessageInTransit::kSubtypeEndpointData) {
+ if (message->subtype() != MessageInTransit::kSubtypeEndpointClientData) {
LOG(WARNING) << "Received message of unexpected subtype: "
<< message->subtype();
return false;
@@ -168,7 +168,6 @@ bool RemoteProducerDataPipeImpl::ProducerEndSerialize(
void RemoteProducerDataPipeImpl::ConsumerClose() {
if (producer_open())
Disconnect();
- DestroyBuffer();
current_num_bytes_ = 0;
}
@@ -446,8 +445,8 @@ void RemoteProducerDataPipeImpl::MarkDataAsConsumed(size_t num_bytes) {
RemoteDataPipeAck ack_data = {};
ack_data.num_bytes_consumed = static_cast<uint32_t>(num_bytes);
scoped_ptr<MessageInTransit> message(
- new MessageInTransit(MessageInTransit::kTypeEndpoint,
- MessageInTransit::kSubtypeEndpointDataPipeAck,
+ new MessageInTransit(MessageInTransit::kTypeEndpointClient,
+ MessageInTransit::kSubtypeEndpointClientDataPipeAck,
static_cast<uint32_t>(sizeof(ack_data)), &ack_data));
if (!channel_endpoint_->EnqueueMessage(message.Pass()))
Disconnect();

Powered by Google App Engine
This is Rietveld 408576698